##  Key Concepts and Features
### Fact Sheets and Meta Model
SAP LeanIX documents the organization's IT landscape and architectural elements using so-called fact sheets. Each architectural object, such as applications, business capabilities, IT components, etc., has its own fact sheet to store relevant information.
There are 12 predefined fact sheet types, each serving as a template with specific attributes and fields. For instance, to capture information about an application, you would use the application fact sheet type. It includes attributes such as lifecycle, technical fit, functional fit, etc. Subsequently, individual fact sheets are created for each application you wish to document.
Fact sheets form the foundation of the meta model. Meta model is like a blueprint that defines the relationships between different architectural elements and how the information in fact sheets is interconnected. For example, business capabilities rely on applications, which, in turn, use IT Components, while organizations use applications and so forth.
The meta model can also be customized to adjust the structure and relationships of architectural elements. However, customizing the meta model should be done thoughtfully, as the out-of-the-box meta model is already well-designed for its intended purpose. To learn more about the meta model and modeling fact sheets, see [Meta Model](https://help.sap.com/docs/leanix/ea/meta-model?locale=en-US&state=PRODUCTION&version=CLOUD "Get an overview of the SAP LeanIX meta model and its key concepts.").
The high-level representation of the out-of-the-box meta model below shows the associated relationships:
![SAP LeanIX Meta Model](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274838927a44101492e2df55cca5b2e0_LowRes.png)
SAP LeanIX Meta Model
### Inventory and Collaboration
The inventory is the centralized repository where you create, add, and manage fact sheets. If you are seeking information from the fact sheets or if you are responsible for maintaining and ensuring the accuracy of the information in a fact sheet, the inventory is your go-to place.
Documenting an organization's IT landscape is a collaborative effort, and contributors such as application owners, business owners, data architects, etc, play an important role. Collaboration features like [surveys](https://help.sap.com/docs/leanix/ea/surveys?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX surveys streamline data collection and collaboration with seamless integration with fact sheets."), [fact sheet subscription](https://help.sap.com/docs/leanix/ea/fact-sheet-subscription?locale=en-US&state=PRODUCTION&version=CLOUD "Fact sheet subscription assigns responsibility and accountability to users for maintaining data. Learn about fact sheet subscriptions, including types, roles, and how to assign and subscribe to fact sheets to promote stakeholder involvement and ensure data accuracy and completeness."), [comments](https://help.sap.com/docs/leanix/ea/collaborating-and-managing-data-in-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD#loio27592c207a441014b142ca56bfa9decf__commenting_on_fact_sheets), and [to-dos](https://help.sap.com/docs/leanix/ea/to-dos?locale=en-US&state=PRODUCTION&version=CLOUD "To-dos facilitate task delegation, collaboration, and governance and can be used to ensure data integrity and quality through transparent task management.") help keep data accurate and up-to-date. Additionally, [fact sheet completeness](https://help.sap.com/docs/leanix/ea/fact-sheet-completeness?locale=en-US&state=PRODUCTION&version=CLOUD "The fact sheet completion score measures the extent of required data filled out for a fact sheet, ensuring data accuracy and completeness. It is based on assigned weights to fields, subsections, and sections.") and [quality seal](https://help.sap.com/docs/leanix/ea/quality-seal?locale=en-US&state=PRODUCTION&version=CLOUD "Quality seal ensures data integrity by assigning approval responsibility to accountable and responsible subscribers of fact sheets. When broken, it prompts verification and approval of fact sheet information.") features assist enterprise architects in tracking the quality and completeness of data.
### Reports and Diagrams
[Reports](https://help.sap.com/docs/leanix/ea/reports?locale=en-US&state=PRODUCTION&version=CLOUD) and [diagrams](https://help.sap.com/docs/leanix/ea/diagrams?locale=en-US&state=PRODUCTION&version=CLOUD) in SAP LeanIX provide visual representations and insights into your enterprise architecture data. You use reports to obtain a clear overview of the as-is and future-state architecture and identify trends, redundancies, and risks. For instance, landscape reports can be used to get a comprehensive view of the IT landscape, matrix reports provide correlations between attributes of different fact sheet types, and roadmap reports can be used to outline strategic initiatives and priorities for future-state architecture.
![Application Landscape Report](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274722c07a441014b0d7930b30056b4f_LowRes.png)
Application Landscape Report
Similarly, diagrams enable you to build visual models of an organization's enterprise architecture. You can break down complex architecture into manageable parts and interactively visualize relationships, data flow, and dependencies between various architectural elements. These visualization and analytical capabilities enable enterprise architects to chart out needed action plans, such as application rationalization, modernization, cloud migration, ERP transformation, etc.
